@@ -7,10 +7,10 @@ import pathlib
 import platform
 import unittest
 import zipfile
-from jsonargparse import LoggerProperty, null_logger, Path
+from jsonargparse import ArgumentParser, LoggerProperty, null_logger, Path
 from jsonargparse.optionals import fsspec_support, import_fsspec, url_support
-from jsonargparse.util import _suppress_stderr
-from jsonargparse_tests.base import responses, responses_activate, TempDirTestCase
+from jsonargparse.util import get_import_path, import_object
+from jsonargparse_tests.base import responses, responses_activate, suppress_stderr, TempDirTestCase
 
 
 @unittest.skipIf(os.name != 'posix' or platform.python_implementation() != 'CPython',
@@ -255,7 +255,7 @@ class LoggingPropertyTests(unittest.TestCase):
     def test_logger_levels(self):
         levels = ['DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL']
         for num, level in enumerate(levels):
-            with self.subTest(level), _suppress_stderr():
+            with self.subTest(level), suppress_stderr():
                 test = self.TestClass(logger={'level': level})
                 with self.assertLogs(level=level) as log:
                     getattr(test.logger, level.lower())(self.log_message)
@@ -269,6 +269,22 @@ class LoggingPropertyTests(unittest.TestCase):
     def test_failure_cases(self):
         self.assertRaises(ValueError, lambda: self.TestClass(logger={'level': 'invalid'}))
         self.assertRaises(ValueError, lambda: self.TestClass(logger=self.TestClass))
+        self.assertRaises(ValueError, lambda: self.TestClass(logger={'invalid': 'value'}))
+
+
+class ImportFunctionsTests(unittest.TestCase):
+
+    def test_import_object_invalid(self):
+        self.assertRaises(ValueError, lambda: import_object(True))
+        self.assertRaises(ValueError, lambda: import_object('jsonargparse-tests.os'))
+
+
+    def test_get_import_path(self):
+        self.assertEqual(get_import_path(ArgumentParser), 'jsonargparse.ArgumentParser')
+        self.assertEqual(get_import_path(ArgumentParser.merge_config), 'jsonargparse.ArgumentParser.merge_config')
+        from email.mime.base import MIMEBase
+        self.assertEqual(get_import_path(MIMEBase), 'email.mime.base.MIMEBase')
+
 
 
 if __name__ == '__main__':
